import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { Door, DoorEvents } from "../misc/Door";
import { SystemStatusEvents } from "./events";
import { ExtractEventTypes } from "@skeldjs/events";
import { Hostable } from "../Hostable";
export interface ElectricalDoorsSystemData {
    doors: boolean[];
}
export declare type ElectricalDoorsSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents & DoorEvents<RoomType> & ExtractEventTypes<[]>;
/**
 * Represents a system for doors that must be manually opened.
 *
 * See {@link ElectricalDoorsSystemEvents} for events to listen to.
 */
export declare class ElectricalDoorsSystem<RoomType extends Hostable = Hostable> extends SystemStatus<ElectricalDoorsSystemData, ElectricalDoorsSystemEvents, RoomType> {
    static systemType: SystemType.Decontamination;
    systemType: SystemType.Decontamination;
    /**
     * The doors in the map.
     */
    doors: Door<RoomType>[];
    constructor(ship: InnerShipStatus<RoomType>, data?: HazelReader | ElectricalDoorsSystemData);
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    private _openDoor;
    /**
     * Open a door by its ID. This is a host operation on official servers.
     * @param doorId the ID of the door to open
     */
    openDoor(doorId: number): Promise<void>;
    private _closeDoor;
    /**
     * Close a door by its ID. This is a host operation on official servers.
     * @param doorId The ID of the door to close.
     */
    closeDoor(doorId: number): Promise<void>;
}
